@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -27,25 +27,22 @@
 #import "OFConcreteDictionary.h"
 #import "OFData.h"
 #import "OFEnumerator.h"
+#import "OFJSONRepresentationPrivate.h"
 #import "OFString.h"
 
 #import "OFInvalidArgumentException.h"
 #import "OFOutOfRangeException.h"
 #import "OFUndefinedKeyException.h"
 
-static struct {
-	Class isa;
-} placeholder;
-
-@interface OFDictionary ()
-- (OFString *)
-    of_JSONRepresentationWithOptions: (OFJSONRepresentationOptions)options
-			       depth: (size_t)depth;
+@interface OFDictionary () <OFJSONRepresentationPrivate>
 @end
 
 @interface OFPlaceholderDictionary: OFDictionary
 @end
 
+@interface OFConcreteDictionarySingleton: OFConcreteDictionary
+@end
+
 OF_DIRECT_MEMBERS
 @interface OFDictionaryObjectEnumerator: OFEnumerator
 {
@@ -56,6 +53,18 @@ OF_DIRECT_MEMBERS
 - (instancetype)initWithDictionary: (OFDictionary *)dictionary;
 @end
 
+static struct {
+	Class isa;
+} placeholder;
+
+static OFConcreteDictionarySingleton *emptyDictionary;
+
+static void
+emptyDictionaryInit(void)
+{
+	emptyDictionary = [[OFConcreteDictionarySingleton alloc] init];
+}
+
 @implementation OFPlaceholderDictionary
 #ifdef __clang__
 /* We intentionally don't call into super, so silence the warning. */
@@ -65,7 +74,9 @@ OF_DIRECT_MEMBERS
 #endif
 - (instancetype)init
 {
-	return (id)[[OFConcreteDictionary alloc] init];
+	static OFOnceControl onceControl = OFOnceControlInitValue;
+	OFOnce(&onceControl, emptyDictionaryInit);
+	return (id)emptyDictionary;
 }
 
 - (instancetype)initWithDictionary: (OFDictionary *)dictionary
@@ -121,6 +132,10 @@ OF_DIRECT_MEMBERS
 OF_SINGLETON_METHODS
 @end
 
+@implementation OFConcreteDictionarySingleton
+OF_SINGLETON_METHODS
+@end
+
 @implementation OFDictionary
 + (void)initialize
 {
