@@ -279,7 +279,7 @@ normalizedKey(OFString *key)
 	} @catch (OFWriteFailedException *e) {
 		id <OFHTTPServerDelegate> delegate = _server.delegate;
 
-#if OF_GCC_VERSION >= 402
+#if defined(__clang__) || OF_GCC_VERSION >= 406
 # pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wdeprecated"
 #endif
@@ -295,7 +295,7 @@ normalizedKey(OFString *key)
 			    didReceiveExceptionForResponse: self
 						   request: _request
 						 exception: e];
-#if OF_GCC_VERSION >= 402
+#if defined(__clang__) || OF_GCC_VERSION >= 406
 # pragma GCC diagnostic pop
 #endif
 	}
@@ -617,10 +617,13 @@ normalizedKey(OFString *key)
 		    server: _server
 		   request: request] autorelease];
 
-	[_server.delegate server: _server
-	       didReceiveRequest: request
-		     requestBody: _requestBody
-			response: response];
+	[_server.delegate performSelector: @selector(server:didReceiveRequest:
+					       requestBody:response:)
+			       withObject: _server
+			       withObject: request
+			       withObject: _requestBody
+			       withObject: response
+			       afterDelay: 0];
 
 	objc_autoreleasePoolPop(pool);
 }
@@ -987,7 +990,7 @@ normalizedKey(OFString *key)
 			return false;
 		}
 
-#if OF_GCC_VERSION >= 402
+#if defined(__clang__) || OF_GCC_VERSION >= 406
 # pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wdeprecated"
 #endif
@@ -995,7 +998,7 @@ normalizedKey(OFString *key)
 		    @selector(server:didReceiveExceptionOnListeningSocket:)])
 			return [_delegate		  server: self
 			    didReceiveExceptionOnListeningSocket: exception];
-#if OF_GCC_VERSION >= 402
+#if defined(__clang__) || OF_GCC_VERSION >= 406
 # pragma GCC diagnostic pop
 #endif
 
