@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -19,13 +19,21 @@
 
 #import "OFTLSStream.h"
 
+#ifdef __clang__
+# pragma clang diagnostic push
+# pragma clang diagnostic ignored "-Wdocumentation-deprecated-sync"
+#endif
 #include <mbedtls/ssl.h>
+#ifdef __clang__
+# pragma clang diagnostic pop
+#endif
 
 OF_ASSUME_NONNULL_BEGIN
 
+OF_SUBCLASSING_RESTRICTED
 @interface OFMbedTLSTLSStream: OFTLSStream <OFStreamDelegate>
 {
-	bool _initialized, _handshakeDone;
+	bool _initialized, _server, _handshakeDone;
 	mbedtls_ssl_config _config;
 	mbedtls_ssl_context _SSL;
 	mbedtls_x509_crt _CAChain;
